# glimix-core

[![PyPIl](https://img.shields.io/pypi/l/glimix-core.svg?style=flat-square)](https://pypi.python.org/pypi/glimix-core/)
[![PyPIv](https://img.shields.io/pypi/v/glimix-core.svg?style=flat-square)](https://pypi.python.org/pypi/glimix-core/)
[![Documentation Status](https://readthedocs.org/projects/glimix-core/badge/?style=flat-square&version=1.2.x)](https://glimix-core.readthedocs.io/)


Fast inference for Generalized Linear Mixed Models.

## Install

You can install it via [pip](https://pypi.python.org/pypi/pip).
First you need to install [liknorm](http://liknorm.readthedocs.io/en/latest/)
library and then
```bash
pip install glimix-core
```

Refer to [documentation](http://glimix-core.readthedocs.io/)
for more information.

## Running the tests

After installation, you can test it
```
python -c "import glimix_core; glimix_core.test()"
```
as long as you have [pytest](http://docs.pytest.org/en/latest/).

If you encounter any issue, please,
[submit it](https://github.com/limix/glimix-core/issues/new).

## Authors

* **Danilo Horta** - [https://github.com/Horta](https://github.com/Horta)

## License

This project is licensed under the MIT License - see the
[LICENSE](LICENSE) file for details
